@@ -32,7 +32,7 @@ def append_orchid_assemblies_directory_path() -> None:
     """
     Append the directory containing the required Orchid assemblies to `sys.path`.
     """
-    orchid_bin_dir = toolz.get_in(['orchid', 'root'], orchid.configuration.python_api())
+    orchid_bin_dir = toolz.get_in(['orchid', 'root'], orchid.configuration.get_configuration())
     if orchid_bin_dir not in sys.path:
         sys.path.append(orchid_bin_dir)
 
